/*
tutorial_#1-01

=====================
Six Online Tutorials:
=====================

The tutorials online propose ideas and approaches, which allow the user to problematize and then practice to do something to use for their own purposes.
Describes the stages of construction of some systems to help the reader, step by step, to learn to do something, to build patchs be used effectively in the performance.
Examples are some ideas to change, expand, or start from scratch using the same ideas or the same solutions and then realize their control systems.

=====================
ONLINE TUTORIAL #1
1. "SOLO [Nr.19]" - Digital set-up for Stockhausen's Composition (by E.Francioni): tutorials #1 - from his analog to my digital setup.
=====================

Before approaching the csd to run SOLO [Nr.19] Karlheinz Stockhausen - algorithm on which rests the 'App written in tandem with "apeSoft" of A.Petrolati, and which will be discussed in the tutorial # 3 - is very important, for the performer, scholar and researcher, prior knowledge of this complex composition.

To that end, here are the resources that are currently available on-line:
- http://csoundjournal.com/issue13/solo_mv_10_1.html - [CsoundJournal, Spring 2010]; an article that explains the code csd with its GUI in the PC version;
- https://www.youtube.com/playlist?list=PLg8oYeHaRUNG6VCxeejNMionYcH_l473J - [YouTube, 2014]; four tutorials that introduce us gradually to the composition, specifically dedicated to users of the App SOLO [Nr.19];
- https://www.youtube.com/watch?v=lu_j9zDWUb0&feature=youtu.be - [YouTube, 2014]; a performance study carried out with the use of the App SOLO [Nr.19];
- https://www.youtube.com/watch?v=5aOr3zjLV0U - [YouTube, 2014]; a live performance with the use of the App SOLO [Nr.19] and in collaboration with the Polytechnic University of Ancona, Italy.

FROM HIS ANALOG TO MY DIGITAL SETUP
Based on the flow chart accompanying the score (SOLO Nr.19, Universal Edition - Wien), first it must understand precisely the signal path;
after a first draft of csd I created another flowchart most comprehensive that it emphasizes:
• the control system of the four assistants (Microphone, Feedback, Playback and Delay);
• the signal path in the two lines (L / R) of stereo and
• references to the main variables that then come into play in the orchestra.

In the examples of the group tutorials #1 I took into account the numerical values of FormSchema - Version I.
For further clarity was necessary to reduce the examples to some parts of FormSchema (for example: the only channel left, only a few Assistants, or some Cycles).

*/

<CsoundSynthesizer>
<CsOptions>
</CsOptions>
<CsInstruments>

; header 

sr 		=	44100
ksmps 		=	128
nchnls 		=	2
0dbfs 		= 	1

/*
In a very rough the csd (almost 7000 lines in the full version) you can reduce all these lines of code: not simply the Technical setup, heart button (next to the explanatory comments).
Obviously this is only a manner of interpreting the flow chart indicated by Stockhausen; I realize full well that there could be other ways of arriving at the same result through the instruments of Csound.
*/

/*
;==================================================================================================================
	instr dummy 				; TECHNICAL_SET-UP
;==================================================================================================================

;==================================================================================================================
; SIGNAL
;==================================================================================================================

asig		inch	1		; import of the microphone signal

;==================================================================================================================
; ASSISTANT_1 - LEFT & RIGHT	-	MICROPHONE
;==================================================================================================================

al_A 	=	asig * kenl1		; input signal multiplied the envelope line of kenl1 (ASSISTANT 1), Left which determines the ON / OFF (1/0)
ar_A 	=	asig * kenr1 		; input signal multiplied the envelope line of kenl1 (ASSISTANT 1), Right which determines the ON / OFF (1/0)

;==================================================================================================================
; VALUE MITIGATION AMPLITUDE SIGNAL
;==================================================================================================================

igain 	=	ivalue 		; value (arbitrary) of attenuation before the delay-line

;==================================================================================================================
;ASSISTANT_4		-	DELAY
;==================================================================================================================

ktdel		line	iTdel, iTCycle, iTdel			; Assistant 4 SWITCH deltapi (delay-line)

;==================================================================================================================
;ASSISTANT_2 - LEFT	-	FEED-BACK
;==================================================================================================================

adummyl 	delayr	imaxdel 				; reads the maximum value of the delay-line (not more than the largest value used for the current Version)
adel_A 	deltapi	ktdel 					; signal taken to delay kdel, variable time for each Cycle (ASSISTANT 4)
awriteL 	=	(al_A + (adel_A * kenl2)) * igain 	; incoming signal + (delayed signal * envelope line of kenl2 ASSISTANT 2, Left) * attenuation value
		delayw	 awriteL 				; he writes in the delay line awriteL

;==================================================================================================================
; ASSISTANT_2 - RIGHT	-	FEED-BACK
;==================================================================================================================

adummyr 	delayr	imaxdel  				; reads the maximum value of the delay-line (not more than the largest value used for the current Version)
ader_A 	deltapi	ktdel 					; signal taken to delay kdel, variable time for each Cycle (ASSISTANT 4)
awriteR 	=	(ar_A + (ader_A * kenr2)) * igain 	; incoming signal + (delayed signal * envelope line of kenl2 ASSISTANT 2, Right) * attenuation value
		delayw awriteR 				; he writes in the delay line awriteL

;==================================================================================================================
;ASSISTANT_3 - LEFT & RIGHT		-	PLAY-BACK
;==================================================================================================================

a_left 		=	adel_A * kenl3 			; Left signal after feedback multiplied the envelope line of kenl3 ASSISTANT 3, Left
a_right 	=	ader_A * kenr3 			; Right after the signal feedback multiplied the envelope line of kenr3 ASSISTANT 3, Right

;==================================================================================================================
;OUT
;==================================================================================================================

		outs	a_left, a_right 				; output (optionally you can add to the processed signal a percentage of the input signal asig)
		
	endin
*/

;==================================================================================================================

/*
Before we go further, however, you must try to analyze closely the operation of the various parts of csd (although simplified) in detail.
Therefore it will split instr dummy in various other instruments much more simplified, making observations and tests to evaluate the outcomes (debug), results that will be of type: numeric, visual and / or auditory.
We'll start with examples on the left channel only, then the most advanced stage of the tutorial # 1, we will pass to the orchestras to two channels to watch the signal path in Left and Right.
*/ 

;==================================================================================================================


</CsInstruments>
<CsScore>

</CsScore>
</CsoundSynthesizer><bsbPanel>
 <label>Widgets</label>
 <objectName/>
 <x>72</x>
 <y>179</y>
 <width>400</width>
 <height>200</height>
 <visible>true</visible>
 <uuid/>
 <bgcolor mode="background">
  <r>204</r>
  <g>204</g>
  <b>204</b>
 </bgcolor>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>19</x>
  <y>30</y>
  <width>538</width>
  <height>100</height>
  <uuid>{c499e384-2f3e-43d9-8cff-5d5f31ad9096}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>CSOUND INSIDE
Enrico Francioni 
"Building Csound-based Systems for Realtime Chamber Music Performance"
TUTORIAL #1-01: "SOLO [Nr.19]" - Digital set-up for Stockhausen's composition - 
from his analog to my digital setup.</label>
  <alignment>center</alignment>
  <font>Arial</font>
  <fontsize>14</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="background">
   <r>204</r>
   <g>204</g>
   <b>204</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
</bsbPanel>
<bsbPresets>
</bsbPresets>
<MacOptions>
Version: 3
Render: Real
Ask: Yes
Functions: ioObject
Listing: Window
WindowBounds: 72 179 400 200
CurrentView: io
IOViewEdit: On
Options:
</MacOptions>

<MacGUI>
ioView background {52428, 52428, 52428}
ioText {19, 30} {538, 100} label 0.000000 0.00100 "" center "Arial" 14 {0, 0, 0} {52224, 52224, 52224} nobackground noborder CSOUND INSIDEÂ¬Enrico Francioni Â¬"Building Csound-based Systems for Realtime Chamber Music Performance"Â¬TUTORIAL #1-01: "SOLO [Nr.19]" - Digital set-up for Stockhausen's composition - Â¬from his analog to my digital setup.
</MacGUI>
