//
//  VerticalSlider.m
//  VerticalSlider
//
//  Created by apeSoft on 28/10/12.
//  Copyright (c) 2012 ape~. All rights reserved.
//

#import "VerticalSlider.h"

@implementation VerticalSlider
@synthesize imageRef;
@synthesize channelName = mChannelName;

- (void) awakeFromNib {
#ifdef LABEL
    [_valueLabel setBackgroundColor:[UIColor clearColor]];
#endif
}

- (id)initWithFrame:(CGRect)frame
{
    self = [super initWithFrame:frame];
    if (self) {
        
        // Horizontal Slider
        [self _sliderSetup];
    }
    return self;
}

- (id)initWithCoder:(NSCoder *)aDecoder {
    self = [super initWithCoder:aDecoder];
    if (self) {
        
        // Horizontal Slider
        [self _sliderSetup];
    }
    return self;
    
}

-(void)_sliderSetup {
    
    // Setup custom slider images
    self.backgroundColor = [UIColor clearColor];
    
    UIImage *tumbImage = [[UIImage imageNamed:@"master_thumb.png"]
                     stretchableImageWithLeftCapWidth:30.0 topCapHeight:0.0];
    
    UIImage *stetchLeftTrack = [[UIImage imageNamed:@"master_min.png"]
                               stretchableImageWithLeftCapWidth:30.0 topCapHeight:0.0];
	UIImage *stetchRightTrack = [[UIImage imageNamed:@"master_max.png"]
                                stretchableImageWithLeftCapWidth:30.0 topCapHeight:0.0];

    
    [self setThumbImage:tumbImage forState:UIControlStateNormal];
    [self setMinimumTrackImage:stetchLeftTrack forState:UIControlStateNormal];
    [self setMaximumTrackImage:stetchRightTrack forState:UIControlStateNormal];
    
    //revert width higth
    self.bounds = CGRectMake(self.bounds.origin.x, self.bounds.origin.y, self.bounds.size.height, self.bounds.size.width);
    self.transform = CGAffineTransformMakeRotation(-0.5*M_PI);
    
    //spring setup
    self.minimumValue = 0.f;
    self.maximumValue = 1.f;
    self.value = 0.0;
    _defaultValue = self.value;
    
#ifdef LABEL
    _valueLabel = [[UILabel alloc] initWithFrame:CGRectZero];
    _valueLabel.backgroundColor = [UIColor clearColor];
    _valueLabel.adjustsFontSizeToFitWidth = YES;
    _valueLabel.minimumScaleFactor = 0.5;
    _valueLabel.textAlignment = NSTextAlignmentLeft;
    _valueLabel.textColor = [UIColor orangeColor];
    _valueLabel.font = [UIFont systemFontOfSize:11];
    _valueLabel.autoresizingMask = UIViewAutoresizingFlexibleWidth;
    _valueLabel.layer.shadowColor = self.layer.shadowColor;
	_valueLabel.layer.shadowOffset = self.layer.shadowOffset;
	_valueLabel.layer.shadowRadius = self.layer.shadowRadius;
	_valueLabel.layer.shadowOpacity = self.layer.shadowOpacity;
    
    //revert width higth
    _valueLabel.bounds = CGRectMake(_valueLabel.bounds.origin.x, _valueLabel.bounds.origin.y,
                                    _valueLabel.bounds.size.height, _valueLabel.bounds.size.width);
    _valueLabel.transform = CGAffineTransformMakeRotation(0.5*M_PI);
    
    [_valueLabel setFrame:CGRectMake(self.bounds.size.width - 25, -25, self.bounds.size.height, self.bounds.size.height)];
    
    [self addSubview:_valueLabel];
#endif
    
}

- (UIImage *)scaleImage:(UIImage *) image maxWidth:(float) maxWidth maxHeight:(float) maxHeight
{
    CGImageRef imgRef = image.CGImage;
    CGFloat width = CGImageGetWidth(imgRef);
    CGFloat height = CGImageGetHeight(imgRef);
    
    if (width <= maxWidth && height <= maxHeight)
    {
        return image;
    }
    
    CGAffineTransform transform = CGAffineTransformIdentity;
    CGRect bounds = CGRectMake(0, 0, width, height);
    
    if (width > maxWidth || height > maxHeight)
    {
        CGFloat ratio = width/height;
        
        if (ratio > 1)
        {
            bounds.size.width = maxWidth;
            bounds.size.height = bounds.size.width / ratio;
        }
        else
        {
            bounds.size.height = maxHeight;
            bounds.size.width = bounds.size.height * ratio;
        }
    }
    
    CGFloat scaleRatio = bounds.size.width / width;
    UIGraphicsBeginImageContext(bounds.size);
    CGContextRef context = UIGraphicsGetCurrentContext();
    CGContextScaleCTM(context, scaleRatio, -scaleRatio);
    CGContextTranslateCTM(context, 0, -height);
    CGContextConcatCTM(context, transform);
    CGContextDrawImage(UIGraphicsGetCurrentContext(), CGRectMake(0, 0, width, height), imgRef);
    
    UIImage *imageCopy = UIGraphicsGetImageFromCurrentImageContext();
    UIGraphicsEndImageContext();
    
    return imageCopy;
    
}

#pragma mark - value accessors
-(float)value {
    [self updateLabel:super.value];
    return super.value;
}

- (void)resetDefaultValue {
    
    self.value = _defaultValue;
}

- (void)updateLabel:(float)value {
    
#ifdef LABEL
    int val =  (float) value * 100.f;
    
    [_valueLabel setText: [NSString stringWithFormat: @"%d %@", val, @"%"]];
#endif
    
}
@end
