/*
tutorial_#1-07

N.B. For tutorials that follow we will consider the Cycle A (the duration of 66 seconds) consists of 11 Periods (duration of 6 seconds each) from the FormSchema Version I.

In tutorial_#1-07 well as bring the code for the Left channel of the first and second Assistant (Microphone and Feedback) with the syntax shown in tutorial_#1-06, is added to the most complex part of the technical-setup:
- the envelope line of the fourth Assistant Delay (not more than one switch of the delay times that goes to the deltapi);
- the real Feedback provided by the use of triplet delayr/deltapi/delayw.
In this tutorial we are still omitted the intervention of third Assistant Playback.

During execution observe the progression of the signal through the Controller, its correspondence with the boxes numbered from 1 to 11 representing the Periods and will verify the presence or absence of the audio signal in correspondence to the colored boxes, but also taking into account the delay and accumulation applied to the same signal.

*/

<CsoundSynthesizer>
<CsOptions>
</CsOptions>
<CsInstruments>

sr 		=	44100
ksmps 		=	128
nchnls 		=	1
0dbfs 		= 	1

gkenl1		init	0
gkenl2		init	0

;==================================================================================================================
	instr 1			; PATCH FOR THE GENERATION OF LINE OF THE ENVELOPE SLIDER ASSISTANT - MICROPHONE
;==================================================================================================================

ia 	= p4
ib 	= p5
ifn1 	= p6
ifn2 	= p7

indx		init	- 1
ilen		=	ftlen(ifn1)

reset:
indx		=	indx + 1
if	indx <= ilen - 1  goto forth
turnoff

forth:
idur		table	indx, ifn1
idur_env	table	indx, ifn2
		timout 0, idur, continue
		reinit reset
continue:

gkenl1		linseg 0, ia, 1, idur_env - (ia + ib), 1, ib, 0

endin

;==================================================================================================================
	instr 2			; PATCH FOR THE GENERATION OF LINE OF THE ENVELOPE SLIDER ASSISTANT - FEEDBACK
;==================================================================================================================

ia 	= p4
ib 	= p5
ifn1 	= p6
ifn2 	= p7

indx		init	- 1
ilen		=	ftlen(ifn1)

reset:
indx		=	indx + 1
if	indx <= ilen - 1  goto forth
turnoff

forth:
idur		table	indx, ifn1
idur_env	table	indx, ifn2
		timout 0, idur, continue
		reinit reset
continue:

gkenl2		linseg 0, ia, 1, idur_env - (ia + ib), 1, ib, 0

endin

;==================================================================================================================
	instr 3				; TECHNICAL_SET-UP
;==================================================================================================================

ksig	invalue "sig"
if i(ksig) == 0 then
asig = 0
elseif i(ksig) == 1 then
asig		inch	1
elseif i(ksig) == 2 then
asig, aright	mp3in	"1-11del.mp3"
endif

;==================================================================================================================
; MICROPHONE - ASSISTANT_1 - LEFT 
;==================================================================================================================

al_A 	=	asig * gkenl1		; input signal multiplied the envelope line of gkenl1 (ASSISTANT 1), Left which determines the ON / OFF (1/0)

;==================================================================================================================
; VALUE MITIGATION AMPLITUDE SIGNAL
;==================================================================================================================

igain 	=	.8 			; value (arbitrary) of attenuation before the delay-line

;==================================================================================================================
;ASSISTANT_4		-	DELAY
;==================================================================================================================

ktdel		linseg	6, 66, 6				; ASSISTANT_4 SWITCH deltapi (delay times) of only CYCLE A - N.B. in the full Version of all Cycles you can generate these values (ktdel) with the same patch used for Assistants

;==================================================================================================================
; FEEDBACK - ASSISTANT_2 - LEFT
;==================================================================================================================

adummyl 	delayr	25.3 					; setting a maximum value of the delay-line (not more than the largest value used for the current Version)
adel_A 	deltapi	ktdel 					; signal taken to delay kdel, variable time for each Cycle (ASSISTANT 4)
awriteL 	=	(al_A + (adel_A * gkenl2)) * igain 	; incoming signal + (delayed signal * envelope line of kenl2 ASSISTANT 2, Left) * attenuation value
		delayw	 awriteL 				; he writes in the delay line awriteL

out	adel_A

outvalue "enL1", gkenl1		; slider in the Widgets Panel
outvalue "enL2", gkenl2		; slider in the Widgets Panel
outvalue "del", ktdel			; knob in the Widgets Panel
ktinst	timeinsts
outvalue "time", ktinst			; time line in Widgets Panel

; BOX ENVELOPES
outvalue	"ONE", 1
outvalue	"ZERO", 0

endin

</CsInstruments>
<CsScore>

;ASSISTANT "1" LEFT		A
f1	0	4	-2	18	18	30
f2	0	4	-2	6	6	18

;ASSISTANT  "2" LEFT	A
f3	0	4	-2	6	36	24
f4	0	4	-2	0	24	24

i1	0	66	 .001	.001	1	2
i2	0	66	 .001	.001	3	4
i3	0	66
e
</CsScore>
</CsoundSynthesizer><bsbPanel>
 <label>Widgets</label>
 <objectName/>
 <x>72</x>
 <y>201</y>
 <width>549</width>
 <height>571</height>
 <visible>true</visible>
 <uuid/>
 <bgcolor mode="background">
  <r>0</r>
  <g>204</g>
  <b>204</b>
 </bgcolor>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>12</x>
  <y>126</y>
  <width>533</width>
  <height>445</height>
  <uuid>{3a856060-50c6-4015-b715-6df204cbd96a}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label/>
  <alignment>left</alignment>
  <font>Arial</font>
  <fontsize>10</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="background">
   <r>153</r>
   <g>204</g>
   <b>102</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>5</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBScope">
  <objectName/>
  <x>453</x>
  <y>133</y>
  <width>80</width>
  <height>64</height>
  <uuid>{41e885d8-8f8e-47bd-b14f-3416933132e9}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <value>-255.00000000</value>
  <type>scope</type>
  <zoomx>1.00000000</zoomx>
  <zoomy>3.00000000</zoomy>
  <dispx>1.00000000</dispx>
  <dispy>1.00000000</dispy>
  <mode>0.00000000</mode>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>11</x>
  <y>16</y>
  <width>538</width>
  <height>100</height>
  <uuid>{951fe7d4-4247-432d-8eee-6e8889420259}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>CSOUND INSIDE
Enrico Francioni 
"Building Csound-based Systems for Realtime Chamber Music Performance"
TUTORIAL #1-07: "SOLO [Nr.19]" - Digital set-up for Stockhausen's composition - 
from his analog to my digital setup.</label>
  <alignment>center</alignment>
  <font>Arial</font>
  <fontsize>14</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="background">
   <r>204</r>
   <g>204</g>
   <b>204</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBDropdown">
  <objectName>sig</objectName>
  <x>25</x>
  <y>221</y>
  <width>74</width>
  <height>23</height>
  <uuid>{deb92c08-53c3-46dc-b624-e51ca5ea7031}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <bsbDropdownItemList>
   <bsbDropdownItem>
    <name>none</name>
    <value>0</value>
    <stringvalue/>
   </bsbDropdownItem>
   <bsbDropdownItem>
    <name>mic</name>
    <value>1</value>
    <stringvalue/>
   </bsbDropdownItem>
   <bsbDropdownItem>
    <name>mp3</name>
    <value>2</value>
    <stringvalue/>
   </bsbDropdownItem>
  </bsbDropdownItemList>
  <selectedIndex>2</selectedIndex>
  <randomizable group="0">false</randomizable>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>163</x>
  <y>239</y>
  <width>31</width>
  <height>31</height>
  <uuid>{4932dc8f-3490-4259-b814-71d7f55f14ff}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>1</label>
  <alignment>center</alignment>
  <font>Arial</font>
  <fontsize>16</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>196</x>
  <y>239</y>
  <width>31</width>
  <height>31</height>
  <uuid>{39461512-c09a-4524-ac26-cecbc0df35a5}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>2</label>
  <alignment>center</alignment>
  <font>Arial</font>
  <fontsize>16</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>229</x>
  <y>239</y>
  <width>31</width>
  <height>31</height>
  <uuid>{a4b737ff-e611-4177-baf0-ace7b82979e5}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>3</label>
  <alignment>center</alignment>
  <font>Arial</font>
  <fontsize>16</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>262</x>
  <y>239</y>
  <width>31</width>
  <height>31</height>
  <uuid>{337e1553-8787-437f-9777-8b12bd35a972}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>4</label>
  <alignment>center</alignment>
  <font>Arial</font>
  <fontsize>16</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>295</x>
  <y>239</y>
  <width>31</width>
  <height>31</height>
  <uuid>{464a4c59-8fc7-4e58-b785-cf7a10e98e63}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>5</label>
  <alignment>center</alignment>
  <font>Arial</font>
  <fontsize>16</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>329</x>
  <y>239</y>
  <width>31</width>
  <height>31</height>
  <uuid>{0882e0ff-a364-48e1-86be-2e524e7f41d7}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>6</label>
  <alignment>center</alignment>
  <font>Arial</font>
  <fontsize>16</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>363</x>
  <y>239</y>
  <width>31</width>
  <height>31</height>
  <uuid>{e85856c7-1a32-41e4-bb37-203ed93d32cf}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>7</label>
  <alignment>center</alignment>
  <font>Arial</font>
  <fontsize>16</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>397</x>
  <y>239</y>
  <width>31</width>
  <height>31</height>
  <uuid>{b4c55a28-592c-4bc8-9447-42e6390bf13d}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>8</label>
  <alignment>center</alignment>
  <font>Arial</font>
  <fontsize>16</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>431</x>
  <y>239</y>
  <width>31</width>
  <height>31</height>
  <uuid>{cf168125-db4c-450c-9349-715d7ad6b7ff}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>9</label>
  <alignment>center</alignment>
  <font>Arial</font>
  <fontsize>16</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>465</x>
  <y>239</y>
  <width>31</width>
  <height>31</height>
  <uuid>{0882580f-a08c-44b0-b4ea-bd49afaf69dc}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>10</label>
  <alignment>center</alignment>
  <font>Arial</font>
  <fontsize>16</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>499</x>
  <y>239</y>
  <width>31</width>
  <height>31</height>
  <uuid>{529683ae-e196-4705-aa38-9a69abcd2483}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>11</label>
  <alignment>center</alignment>
  <font>Arial</font>
  <fontsize>16</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>159</x>
  <y>155</y>
  <width>46</width>
  <height>46</height>
  <uuid>{2d646d86-213b-47c6-b1b2-289b58a0c21e}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>A</label>
  <alignment>center</alignment>
  <font>Arial</font>
  <fontsize>30</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>3</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>207</x>
  <y>170</y>
  <width>44</width>
  <height>25</height>
  <uuid>{08bb81f0-106e-4a74-a69c-7f4c539130d7}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>(66 s)</label>
  <alignment>center</alignment>
  <font>Arial</font>
  <fontsize>12</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBController">
  <objectName>time</objectName>
  <x>163</x>
  <y>278</y>
  <width>366</width>
  <height>12</height>
  <uuid>{66fd5fed-1d3e-4e68-899c-f627c0ecdd86}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>time</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>66.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>65.99981689</xValue>
  <yValue>65.99981689</yValue>
  <type>fill</type>
  <pointsize>1</pointsize>
  <fadeSpeed>0.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>0</r>
   <g>234</g>
   <b>0</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>29</x>
  <y>263</y>
  <width>110</width>
  <height>28</height>
  <uuid>{1ba2dd9c-618c-412d-b4f7-b314a5bb62a8}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>SOLOIST</label>
  <alignment>center</alignment>
  <font>Arial</font>
  <fontsize>12</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="background">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>27</x>
  <y>345</y>
  <width>110</width>
  <height>28</height>
  <uuid>{113057c0-c2a7-4033-ba49-159f600f5b0c}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>MICROPHONE</label>
  <alignment>center</alignment>
  <font>Arial</font>
  <fontsize>12</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="background">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBController">
  <objectName>time</objectName>
  <x>164</x>
  <y>362</y>
  <width>366</width>
  <height>12</height>
  <uuid>{901178fe-d781-4cd7-9e14-cacbdcc21e3b}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>time</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>66.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>65.99981689</xValue>
  <yValue>65.99981689</yValue>
  <type>fill</type>
  <pointsize>1</pointsize>
  <fadeSpeed>0.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>0</r>
   <g>234</g>
   <b>0</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>27</x>
  <y>434</y>
  <width>110</width>
  <height>28</height>
  <uuid>{b51d7307-d88f-4d56-aebe-8b13d85cfa73}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>FEEDBACK</label>
  <alignment>center</alignment>
  <font>Arial</font>
  <fontsize>12</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="background">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>28</x>
  <y>511</y>
  <width>110</width>
  <height>28</height>
  <uuid>{1b09316f-08b3-4bc0-9c50-a425394f890d}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>DELAY</label>
  <alignment>center</alignment>
  <font>Arial</font>
  <fontsize>12</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="background">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBScrollNumber">
  <objectName>del</objectName>
  <x>196</x>
  <y>514</y>
  <width>51</width>
  <height>24</height>
  <uuid>{aa60b70f-e0bc-432a-be68-723f08cbea23}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <alignment>right</alignment>
  <font>Arial</font>
  <fontsize>16</fontsize>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="background">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <value>6.00000000</value>
  <resolution>0.10000000</resolution>
  <minimum>0.00000000</minimum>
  <maximum>30.00000000</maximum>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
  <randomizable group="0">false</randomizable>
  <mouseControl act=""/>
 </bsbObject>
 <bsbObject version="2" type="BSBKnob">
  <objectName>del</objectName>
  <x>141</x>
  <y>502</y>
  <width>51</width>
  <height>50</height>
  <uuid>{c139629d-1986-4d62-91f7-32c50f6165fb}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <minimum>0.00000000</minimum>
  <maximum>30.00000000</maximum>
  <value>6.00000000</value>
  <mode>lin</mode>
  <mouseControl act="jump">continuous</mouseControl>
  <resolution>0.01000000</resolution>
  <randomizable group="0">false</randomizable>
 </bsbObject>
 <bsbObject version="2" type="BSBController">
  <objectName>time</objectName>
  <x>165</x>
  <y>451</y>
  <width>366</width>
  <height>12</height>
  <uuid>{97037858-3e19-440e-85e7-b23d505cdf76}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>time</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>66.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>65.99981689</xValue>
  <yValue>65.99981689</yValue>
  <type>fill</type>
  <pointsize>1</pointsize>
  <fadeSpeed>0.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>0</r>
   <g>234</g>
   <b>0</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject version="2" type="BSBVSlider">
  <objectName>enL1</objectName>
  <x>140</x>
  <y>319</y>
  <width>20</width>
  <height>55</height>
  <uuid>{90ab888f-67f6-492d-b504-3612b53d7a78}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <minimum>0.00000000</minimum>
  <maximum>1.00000000</maximum>
  <value>0.00000000</value>
  <mode>lin</mode>
  <mouseControl act="jump">continuous</mouseControl>
  <resolution>-1.00000000</resolution>
  <randomizable group="0">false</randomizable>
 </bsbObject>
 <bsbObject version="2" type="BSBVSlider">
  <objectName>enL2</objectName>
  <x>140</x>
  <y>409</y>
  <width>20</width>
  <height>55</height>
  <uuid>{f89942de-0e36-4004-96e8-350d89989c60}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <minimum>0.00000000</minimum>
  <maximum>1.00000000</maximum>
  <value>1.00000000</value>
  <mode>lin</mode>
  <mouseControl act="jump">continuous</mouseControl>
  <resolution>-1.00000000</resolution>
  <randomizable group="0">false</randomizable>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>300</x>
  <y>162</y>
  <width>84</width>
  <height>29</height>
  <uuid>{7b2b3776-198a-49dc-b827-dc682ff1f364}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>11 * 6 sec</label>
  <alignment>center</alignment>
  <font>Arial</font>
  <fontsize>16</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBScrollNumber">
  <objectName>time</objectName>
  <x>100</x>
  <y>221</y>
  <width>41</width>
  <height>24</height>
  <uuid>{7ea2d329-01f3-46a3-b3e6-7a8f9187950d}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <alignment>right</alignment>
  <font>Arial</font>
  <fontsize>14</fontsize>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="background">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <value>65.99981689</value>
  <resolution>0.10000000</resolution>
  <minimum>0.00000000</minimum>
  <maximum>66.00000000</maximum>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
  <randomizable group="0">false</randomizable>
  <mouseControl act=""/>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>28</x>
  <y>195</y>
  <width>68</width>
  <height>25</height>
  <uuid>{261091c2-3b40-4bb7-9458-39c8d22ea8d1}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>signal</label>
  <alignment>center</alignment>
  <font>Arial</font>
  <fontsize>10</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>99</x>
  <y>195</y>
  <width>42</width>
  <height>25</height>
  <uuid>{b06cce13-8730-4e7a-905a-67375e0d1f67}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>time</label>
  <alignment>center</alignment>
  <font>Arial</font>
  <fontsize>10</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>140</x>
  <y>298</y>
  <width>20</width>
  <height>20</height>
  <uuid>{4a32c682-2303-47bc-b2f6-2e928995fc25}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>L</label>
  <alignment>center</alignment>
  <font>Arial</font>
  <fontsize>8</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>140</x>
  <y>388</y>
  <width>20</width>
  <height>20</height>
  <uuid>{c0e47b13-26c6-4082-abd7-d036e22e05f5}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>L</label>
  <alignment>center</alignment>
  <font>Arial</font>
  <fontsize>8</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBController">
  <objectName>ONE</objectName>
  <x>164</x>
  <y>321</y>
  <width>31</width>
  <height>31</height>
  <uuid>{47276080-6012-4dab-83f6-20ff6169b4b7}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>ONE</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>1.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>1.00000000</xValue>
  <yValue>1.00000000</yValue>
  <type>fill</type>
  <pointsize>1</pointsize>
  <fadeSpeed>0.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>0</r>
   <g>234</g>
   <b>0</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject version="2" type="BSBController">
  <objectName>ZERO</objectName>
  <x>197</x>
  <y>321</y>
  <width>31</width>
  <height>31</height>
  <uuid>{1dd7f3ce-6f78-48c6-b167-a6bd0fcfdb98}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>ZERO</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>1.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>0.00000000</xValue>
  <yValue>0.00000000</yValue>
  <type>fill</type>
  <pointsize>1</pointsize>
  <fadeSpeed>0.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>0</r>
   <g>234</g>
   <b>0</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject version="2" type="BSBController">
  <objectName>ZERO</objectName>
  <x>230</x>
  <y>321</y>
  <width>31</width>
  <height>31</height>
  <uuid>{620ac27f-96f4-4a26-a18c-2049508fa067}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>ZERO</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>1.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>0.00000000</xValue>
  <yValue>0.00000000</yValue>
  <type>fill</type>
  <pointsize>1</pointsize>
  <fadeSpeed>0.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>0</r>
   <g>234</g>
   <b>0</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject version="2" type="BSBController">
  <objectName>ONE</objectName>
  <x>263</x>
  <y>321</y>
  <width>31</width>
  <height>31</height>
  <uuid>{31670b9a-10b1-4eda-970d-99b91a1e46a6}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>ONE</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>1.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>1.00000000</xValue>
  <yValue>1.00000000</yValue>
  <type>fill</type>
  <pointsize>1</pointsize>
  <fadeSpeed>0.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>0</r>
   <g>234</g>
   <b>0</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject version="2" type="BSBController">
  <objectName>ZERO</objectName>
  <x>296</x>
  <y>321</y>
  <width>31</width>
  <height>31</height>
  <uuid>{098f7227-3820-4292-b907-307acbff012b}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>ZERO</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>1.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>0.00000000</xValue>
  <yValue>0.00000000</yValue>
  <type>fill</type>
  <pointsize>1</pointsize>
  <fadeSpeed>0.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>0</r>
   <g>234</g>
   <b>0</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject version="2" type="BSBController">
  <objectName>ZERO</objectName>
  <x>329</x>
  <y>321</y>
  <width>31</width>
  <height>31</height>
  <uuid>{9b9a736f-c073-4c12-8749-3da9f78dd968}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>ZERO</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>1.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>0.00000000</xValue>
  <yValue>0.00000000</yValue>
  <type>fill</type>
  <pointsize>1</pointsize>
  <fadeSpeed>0.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>0</r>
   <g>234</g>
   <b>0</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject version="2" type="BSBController">
  <objectName>ONE</objectName>
  <x>363</x>
  <y>321</y>
  <width>31</width>
  <height>31</height>
  <uuid>{e224f67d-2a55-4ee2-82c6-70f3856a2b5d}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>ONE</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>1.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>1.00000000</xValue>
  <yValue>1.00000000</yValue>
  <type>fill</type>
  <pointsize>1</pointsize>
  <fadeSpeed>0.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>0</r>
   <g>234</g>
   <b>0</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject version="2" type="BSBController">
  <objectName>ONE</objectName>
  <x>397</x>
  <y>321</y>
  <width>31</width>
  <height>31</height>
  <uuid>{f64aea45-28d6-479f-ab74-91916937c877}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>ONE</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>1.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>1.00000000</xValue>
  <yValue>1.00000000</yValue>
  <type>fill</type>
  <pointsize>1</pointsize>
  <fadeSpeed>0.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>0</r>
   <g>234</g>
   <b>0</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject version="2" type="BSBController">
  <objectName>ONE</objectName>
  <x>431</x>
  <y>321</y>
  <width>31</width>
  <height>31</height>
  <uuid>{ccf5fcc2-4afc-4a45-beac-a9efb1dc31a4}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>ONE</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>1.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>1.00000000</xValue>
  <yValue>1.00000000</yValue>
  <type>fill</type>
  <pointsize>1</pointsize>
  <fadeSpeed>0.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>0</r>
   <g>234</g>
   <b>0</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject version="2" type="BSBController">
  <objectName>ZERO</objectName>
  <x>465</x>
  <y>321</y>
  <width>31</width>
  <height>31</height>
  <uuid>{07a4ed4f-3cec-4ce4-91ed-dbce185d27e0}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>ZERO</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>1.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>0.00000000</xValue>
  <yValue>0.00000000</yValue>
  <type>fill</type>
  <pointsize>1</pointsize>
  <fadeSpeed>0.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>0</r>
   <g>234</g>
   <b>0</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject version="2" type="BSBController">
  <objectName>ZERO</objectName>
  <x>499</x>
  <y>321</y>
  <width>31</width>
  <height>31</height>
  <uuid>{47095f91-bc72-4033-b8c4-9d85f4bc11a7}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>ZERO</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>1.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>0.00000000</xValue>
  <yValue>0.00000000</yValue>
  <type>fill</type>
  <pointsize>1</pointsize>
  <fadeSpeed>0.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>0</r>
   <g>234</g>
   <b>0</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject version="2" type="BSBController">
  <objectName>ZERO</objectName>
  <x>165</x>
  <y>412</y>
  <width>31</width>
  <height>31</height>
  <uuid>{f0106aa1-264e-4445-8289-db85d06d1aa0}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>ZERO</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>1.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>0.00000000</xValue>
  <yValue>0.00000000</yValue>
  <type>fill</type>
  <pointsize>1</pointsize>
  <fadeSpeed>0.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>0</r>
   <g>234</g>
   <b>0</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject version="2" type="BSBController">
  <objectName>ONE</objectName>
  <x>198</x>
  <y>412</y>
  <width>31</width>
  <height>31</height>
  <uuid>{dcbf6c27-aed2-4d81-a95f-a2705c727d05}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>ONE</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>1.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>1.00000000</xValue>
  <yValue>1.00000000</yValue>
  <type>fill</type>
  <pointsize>1</pointsize>
  <fadeSpeed>0.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>0</r>
   <g>234</g>
   <b>0</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject version="2" type="BSBController">
  <objectName>ONE</objectName>
  <x>231</x>
  <y>412</y>
  <width>31</width>
  <height>31</height>
  <uuid>{daaf450e-b3a5-422b-9fc5-f8c9a8f2f0a3}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>ONE</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>1.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>1.00000000</xValue>
  <yValue>1.00000000</yValue>
  <type>fill</type>
  <pointsize>1</pointsize>
  <fadeSpeed>0.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>0</r>
   <g>234</g>
   <b>0</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject version="2" type="BSBController">
  <objectName>ONE</objectName>
  <x>264</x>
  <y>412</y>
  <width>31</width>
  <height>31</height>
  <uuid>{f4b14ae5-8a2e-4bd8-8a99-436e06238797}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>ONE</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>1.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>1.00000000</xValue>
  <yValue>1.00000000</yValue>
  <type>fill</type>
  <pointsize>1</pointsize>
  <fadeSpeed>0.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>0</r>
   <g>234</g>
   <b>0</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject version="2" type="BSBController">
  <objectName>ONE</objectName>
  <x>297</x>
  <y>412</y>
  <width>31</width>
  <height>31</height>
  <uuid>{9a73dc0e-cd8d-403a-a837-f4d9967545b9}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>ONE</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>1.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>1.00000000</xValue>
  <yValue>1.00000000</yValue>
  <type>fill</type>
  <pointsize>1</pointsize>
  <fadeSpeed>0.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>0</r>
   <g>234</g>
   <b>0</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject version="2" type="BSBController">
  <objectName>ZERO</objectName>
  <x>330</x>
  <y>412</y>
  <width>31</width>
  <height>31</height>
  <uuid>{29a2180c-5c6f-465a-92c2-90302004fb57}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>ZERO</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>1.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>0.00000000</xValue>
  <yValue>0.00000000</yValue>
  <type>fill</type>
  <pointsize>1</pointsize>
  <fadeSpeed>0.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>0</r>
   <g>234</g>
   <b>0</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject version="2" type="BSBController">
  <objectName>ZERO</objectName>
  <x>364</x>
  <y>412</y>
  <width>31</width>
  <height>31</height>
  <uuid>{dac8d77f-f7a1-422b-89c9-e4230c77bb30}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>ZERO</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>1.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>0.00000000</xValue>
  <yValue>0.00000000</yValue>
  <type>fill</type>
  <pointsize>1</pointsize>
  <fadeSpeed>0.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>0</r>
   <g>234</g>
   <b>0</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject version="2" type="BSBController">
  <objectName>ONE</objectName>
  <x>398</x>
  <y>412</y>
  <width>31</width>
  <height>31</height>
  <uuid>{51c9bae3-5f43-4e5f-a4fd-dc85ecd9fd5c}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>ONE</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>1.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>1.00000000</xValue>
  <yValue>1.00000000</yValue>
  <type>fill</type>
  <pointsize>1</pointsize>
  <fadeSpeed>0.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>0</r>
   <g>234</g>
   <b>0</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject version="2" type="BSBController">
  <objectName>ONE</objectName>
  <x>432</x>
  <y>412</y>
  <width>31</width>
  <height>31</height>
  <uuid>{c233522f-09f2-4d8f-b6a7-37263d1b77cb}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>ONE</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>1.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>1.00000000</xValue>
  <yValue>1.00000000</yValue>
  <type>fill</type>
  <pointsize>1</pointsize>
  <fadeSpeed>0.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>0</r>
   <g>234</g>
   <b>0</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject version="2" type="BSBController">
  <objectName>ONE</objectName>
  <x>466</x>
  <y>412</y>
  <width>31</width>
  <height>31</height>
  <uuid>{2297e3d6-aa15-42ba-a704-741185feb4f3}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>ONE</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>1.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>1.00000000</xValue>
  <yValue>1.00000000</yValue>
  <type>fill</type>
  <pointsize>1</pointsize>
  <fadeSpeed>0.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>0</r>
   <g>234</g>
   <b>0</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject version="2" type="BSBController">
  <objectName>ONE</objectName>
  <x>500</x>
  <y>412</y>
  <width>31</width>
  <height>31</height>
  <uuid>{c0c421cf-5f9f-4179-bbb2-742ff468ac56}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>ONE</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>1.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>1.00000000</xValue>
  <yValue>1.00000000</yValue>
  <type>fill</type>
  <pointsize>1</pointsize>
  <fadeSpeed>0.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>0</r>
   <g>234</g>
   <b>0</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
</bsbPanel>
<bsbPresets>
</bsbPresets>
<MacOptions>
Version: 3
Render: Real
Ask: Yes
Functions: ioObject
Listing: Window
WindowBounds: 72 179 400 200
CurrentView: io
IOViewEdit: On
Options:
</MacOptions>

<MacGUI>
ioView background {0, 52428, 52428}
ioText {12, 126} {533, 445} label 0.000000 0.00100 "" left "Arial" 10 {0, 0, 0} {39168, 52224, 26112} nobackground noborder 
ioGraph {453, 133} {80, 64} scope 1.000000 -255 
ioText {11, 16} {538, 100} label 0.000000 0.00100 "" center "Arial" 14 {0, 0, 0} {52224, 52224, 52224} nobackground noborder CSOUND INSIDEÂ¬Enrico Francioni Â¬"Building Csound-based Systems for Realtime Chamber Music Performance"Â¬TUTORIAL #1-07: "SOLO [Nr.19]" - Digital set-up for Stockhausen's composition - Â¬from his analog to my digital setup.
ioMenu {25, 221} {74, 23} 2 303 "none,mic,mp3" sig
ioText {163, 239} {31, 31} label 1.000000 0.00100 "" center "Arial" 16 {0, 0, 0} {65280, 65280, 65280} nobackground noborder 1
ioText {196, 239} {31, 31} label 2.000000 0.00100 "" center "Arial" 16 {0, 0, 0} {65280, 65280, 65280} nobackground noborder 2
ioText {229, 239} {31, 31} label 3.000000 0.00100 "" center "Arial" 16 {0, 0, 0} {65280, 65280, 65280} nobackground noborder 3
ioText {262, 239} {31, 31} label 4.000000 0.00100 "" center "Arial" 16 {0, 0, 0} {65280, 65280, 65280} nobackground noborder 4
ioText {295, 239} {31, 31} label 5.000000 0.00100 "" center "Arial" 16 {0, 0, 0} {65280, 65280, 65280} nobackground noborder 5
ioText {329, 239} {31, 31} label 6.000000 0.00100 "" center "Arial" 16 {0, 0, 0} {65280, 65280, 65280} nobackground noborder 6
ioText {363, 239} {31, 31} label 7.000000 0.00100 "" center "Arial" 16 {0, 0, 0} {65280, 65280, 65280} nobackground noborder 7
ioText {397, 239} {31, 31} label 8.000000 0.00100 "" center "Arial" 16 {0, 0, 0} {65280, 65280, 65280} nobackground noborder 8
ioText {431, 239} {31, 31} label 9.000000 0.00100 "" center "Arial" 16 {0, 0, 0} {65280, 65280, 65280} nobackground noborder 9
ioText {465, 239} {31, 31} label 10.000000 0.00100 "" center "Arial" 16 {0, 0, 0} {65280, 65280, 65280} nobackground noborder 10
ioText {499, 239} {31, 31} label 11.000000 0.00100 "" center "Arial" 16 {0, 0, 0} {65280, 65280, 65280} nobackground noborder 11
ioText {159, 155} {46, 46} label 0.000000 0.00100 "" center "Arial" 30 {0, 0, 0} {65280, 65280, 65280} nobackground noborder A
ioText {207, 170} {44, 25} label 0.000000 0.00100 "" center "Arial" 12 {0, 0, 0} {65280, 65280, 65280} nobackground noborder (66 s)
ioMeter {163, 278} {366, 12} {0, 59904, 0} "time" 65.999817 "time" 65.999817 fill 1 0 mouse
ioText {29, 263} {110, 28} label 0.000000 0.00100 "" center "Arial" 12 {0, 0, 0} {65280, 65280, 65280} nobackground noborder SOLOIST
ioText {27, 345} {110, 28} label 0.000000 0.00100 "" center "Arial" 12 {0, 0, 0} {65280, 65280, 65280} nobackground noborder MICROPHONE
ioMeter {164, 362} {366, 12} {0, 59904, 0} "time" 65.999817 "time" 65.999817 fill 1 0 mouse
ioText {27, 434} {110, 28} label 0.000000 0.00100 "" center "Arial" 12 {0, 0, 0} {65280, 65280, 65280} nobackground noborder FEEDBACK
ioText {28, 511} {110, 28} label 0.000000 0.00100 "" center "Arial" 12 {0, 0, 0} {65280, 65280, 65280} nobackground noborder DELAY
ioText {196, 514} {51, 24} scroll 6.000000 0.100000 "del" right "Arial" 16 {0, 0, 0} {65280, 65280, 65280} background noborder 
ioKnob {141, 502} {51, 50} 30.000000 0.000000 0.010000 6.000000 del
ioMeter {165, 451} {366, 12} {0, 59904, 0} "time" 65.999817 "time" 65.999817 fill 1 0 mouse
ioSlider {140, 319} {20, 55} 0.000000 1.000000 0.000000 enL1
ioSlider {140, 409} {20, 55} 0.000000 1.000000 1.000000 enL2
ioText {300, 162} {84, 29} label 0.000000 0.00100 "" center "Arial" 16 {0, 0, 0} {65280, 65280, 65280} nobackground noborder 11 * 6 sec
ioText {100, 221} {41, 24} scroll 65.999817 0.100000 "time" right "Arial" 14 {0, 0, 0} {65280, 65280, 65280} background noborder 
ioText {28, 195} {68, 25} label 0.000000 0.00100 "" center "Arial" 10 {0, 0, 0} {65280, 65280, 65280} nobackground noborder signal
ioText {99, 195} {42, 25} label 0.000000 0.00100 "" center "Arial" 10 {0, 0, 0} {65280, 65280, 65280} nobackground noborder time
ioText {140, 298} {20, 20} label 0.000000 0.00100 "" center "Arial" 8 {0, 0, 0} {65280, 65280, 65280} nobackground noborder L
ioText {140, 388} {20, 20} label 0.000000 0.00100 "" center "Arial" 8 {0, 0, 0} {65280, 65280, 65280} nobackground noborder L
ioMeter {164, 321} {31, 31} {0, 59904, 0} "ONE" 1.000000 "ONE" 1.000000 fill 1 0 mouse
ioMeter {197, 321} {31, 31} {0, 59904, 0} "ZERO" 0.000000 "ZERO" 0.000000 fill 1 0 mouse
ioMeter {230, 321} {31, 31} {0, 59904, 0} "ZERO" 0.000000 "ZERO" 0.000000 fill 1 0 mouse
ioMeter {263, 321} {31, 31} {0, 59904, 0} "ONE" 1.000000 "ONE" 1.000000 fill 1 0 mouse
ioMeter {296, 321} {31, 31} {0, 59904, 0} "ZERO" 0.000000 "ZERO" 0.000000 fill 1 0 mouse
ioMeter {329, 321} {31, 31} {0, 59904, 0} "ZERO" 0.000000 "ZERO" 0.000000 fill 1 0 mouse
ioMeter {363, 321} {31, 31} {0, 59904, 0} "ONE" 1.000000 "ONE" 1.000000 fill 1 0 mouse
ioMeter {397, 321} {31, 31} {0, 59904, 0} "ONE" 1.000000 "ONE" 1.000000 fill 1 0 mouse
ioMeter {431, 321} {31, 31} {0, 59904, 0} "ONE" 1.000000 "ONE" 1.000000 fill 1 0 mouse
ioMeter {465, 321} {31, 31} {0, 59904, 0} "ZERO" 0.000000 "ZERO" 0.000000 fill 1 0 mouse
ioMeter {499, 321} {31, 31} {0, 59904, 0} "ZERO" 0.000000 "ZERO" 0.000000 fill 1 0 mouse
ioMeter {165, 412} {31, 31} {0, 59904, 0} "ZERO" 0.000000 "ZERO" 0.000000 fill 1 0 mouse
ioMeter {198, 412} {31, 31} {0, 59904, 0} "ONE" 1.000000 "ONE" 1.000000 fill 1 0 mouse
ioMeter {231, 412} {31, 31} {0, 59904, 0} "ONE" 1.000000 "ONE" 1.000000 fill 1 0 mouse
ioMeter {264, 412} {31, 31} {0, 59904, 0} "ONE" 1.000000 "ONE" 1.000000 fill 1 0 mouse
ioMeter {297, 412} {31, 31} {0, 59904, 0} "ONE" 1.000000 "ONE" 1.000000 fill 1 0 mouse
ioMeter {330, 412} {31, 31} {0, 59904, 0} "ZERO" 0.000000 "ZERO" 0.000000 fill 1 0 mouse
ioMeter {364, 412} {31, 31} {0, 59904, 0} "ZERO" 0.000000 "ZERO" 0.000000 fill 1 0 mouse
ioMeter {398, 412} {31, 31} {0, 59904, 0} "ONE" 1.000000 "ONE" 1.000000 fill 1 0 mouse
ioMeter {432, 412} {31, 31} {0, 59904, 0} "ONE" 1.000000 "ONE" 1.000000 fill 1 0 mouse
ioMeter {466, 412} {31, 31} {0, 59904, 0} "ONE" 1.000000 "ONE" 1.000000 fill 1 0 mouse
ioMeter {500, 412} {31, 31} {0, 59904, 0} "ONE" 1.000000 "ONE" 1.000000 fill 1 0 mouse
</MacGUI>
